@@ -468,6 +468,7 @@ GSM_PhoneModel allmodels[] = {
 						F_SMS_SM, F_SMS_ME,
 						F_SMS_UTF8_ENCODED,
 						F_READ_SMSTEXTMODE,
+						F_FORCE_UTF8,
 						F_NO_UTF8, F_SAMSUNG_UTF8,
 						F_TSSPCSW, F_OBEX, F_IRMC_LEVEL_2, 0}},
 
@@ -940,6 +941,7 @@ GSM_PhoneModel allmodels[] = {
 	{"E162G",	"E162G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
 	{"E169",	"E169",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
 	{"E169G",	"E169G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+	{"E171",	"E171",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
 	{"E173",	"E173",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
 	{"E1556",	"E1556",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
 	{"E1550",	"E1550",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
